@@ -1,4 +1,4 @@
-#from rauc_handler import RaucHandler
+from rauc_handler import RaucHandler
 from base_service import BaseService
 from pathlib import Path
 from signalrcore.hub_connection_builder import HubConnectionBuilder
@@ -39,7 +39,7 @@ class microServiceBusHandler(BaseService):
 
         self.service_path = f"{self.msb_dir}/services"
         self.msb_settings_path = f"{self.msb_dir}/settings.json"
-        #self.rauc_handler = RaucHandler()
+        self.rauc_handler = RaucHandler()
         super(microServiceBusHandler, self).__init__(id, queue)
     # endregion
     # region Base functions
